<a id="widgets.persistent_tab_widget.*"></a>

## \*

<a id="widgets.persistent_tab_widget.PersistentTabWidget"></a>

## PersistentTabWidget Objects

```python
class PersistentTabWidget(QTabWidget)
```

<a id="widgets.persistent_tab_widget.PersistentTabWidget.__init__"></a>

#### \_\_init\_\_

```python
def __init__(name, tabs=None, *args, **kwargs)
```

<a id="widgets.persistent_tab_widget.PersistentTabWidget.menu"></a>

#### menu

```python
def menu(pos) -> None
```

<a id="widgets.persistent_tab_widget.PersistentTabWidget.unhide_all"></a>

#### unhide\_all

```python
def unhide_all()
```

<a id="widgets.persistent_tab_widget.PersistentTabWidget.restore_state"></a>

#### restore\_state

```python
def restore_state(tabs=None)
```

<a id="widgets.persistent_tab_widget.PersistentTabWidget.tab_order"></a>

#### tab\_order

```python
def tab_order()
```

<a id="widgets.persistent_tab_widget.PersistentTabWidget.visible_tabs"></a>

#### visible\_tabs

```python
def visible_tabs()
```

<a id="widgets.persistent_tab_widget.PersistentTabWidget.move_tab"></a>

#### move\_tab

```python
def move_tab(old, new)
```

<a id="widgets.persistent_tab_widget.PersistentTabWidget.close_tab"></a>

#### close\_tab

```python
def close_tab(index)
```

